Forms Example
===============================================================================

:download:`forms.enaml <../../../examples/containers/forms.enaml>`

.. literalinclude:: ../../../examples/containers/forms.enaml
    :language: python

::

 $ enaml-run forms.enaml

.. image:: images/forms.png
